==> spip_4.2.9+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_ast.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=ast
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_effacer_statistiques' => 'Desaniciar les estadístiques', # MODIF

	// I
	'icone_evolution_visites' => 'Evolución de les visites<br />@visites@ visites',
	'icone_repartition_actuelle' => 'Amosar el repartu actual',
	'icone_repartition_visites' => 'Repartu de les visites',
	'icone_statistiques_visites' => 'Estadístiques',
	'info_affichier_visites_articles_plus_visites' => 'Amosar les visites pa <b>los artículos más visitaos dende l’entamu:</b>',
	'info_comment_lire_tableau' => 'Cómo lleer esti cuadru',
	'info_forum_statistiques' => 'Estadístiques de les visites',
	'info_popularite_2' => 'popularidá del sitiu:',
	'info_popularite_3' => 'popularidá: @popularite@; visites: @visites@',
	'info_popularite_5' => 'popularidá:',
	'info_question_vignettes_referer' => 'Cuando consultes les estadístiques, pues amosar miniatures de los sitios d’orixe de les visites', # MODIF
	'info_question_vignettes_referer_oui' => 'Amosar captures de los sitios d’orixe de les visites',
	'info_visites' => 'visites:',
	'info_visites_plus_populaires' => 'Amosar les visites de <b>los artículos más populares</b> y de <b>los caberos artículos espublizaos:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Xestionar les estadístiques', # MODIF

	// O
	'onglet_origine_visites' => 'Orixe de les visites',
	'onglet_repartition_debut' => 'dende l’entamu',
	'onglet_repartition_lang' => 'Repartío por llingües',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_admin_effacer_stats' => 'Esta orde esborra tolos datos tocantes a les estadístiques de visites al sitiu, incluyendo la popularidá de los artículos.',
	'texte_comment_lire_tableau' => 'El rangu de l’artículu, na clasificación por popularidá, vién indicáu nel marxe; la popularidá de l’artículu (una estimación del númberu de visites diaries que recibirá si el ritmu actual de consultes se mantuviere) y el númberu de visites recibíes dende’l so espublizamientu amuésense na burbuya que apaez al pasar el mur pol títulu.',
	'texte_signification' => 'Les barres escures representen les entráes acumuláes (total de les sub-estayes), les barres clares el númberu de visites pa cada estaya.',
	'titre_evolution_visite' => 'Evolución de les visites',
	'titre_liens_entrants' => 'Enllaces entrantes',
	'titre_page_statistiques' => 'Estadístiques por estayes',
	'titre_page_statistiques_visites' => 'Estadístiques de les visites'
);

==> spip_4.4.7+dfsg.orig.tar.xz: plugins-dist/statistiques/lang/statistiques_ast.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/statistiques?lang_cible=ast
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_effacer_statistiques' => 'Desaniciar les estadístiques', # MODIF

	// I
	'icone_evolution_visites' => 'Evolución de les visites<br />@visites@ visites',
	'icone_repartition_actuelle' => 'Amosar el repartu actual',
	'icone_repartition_visites' => 'Repartu de les visites',
	'icone_statistiques_visites' => 'Estadístiques',
	'info_affichier_visites_articles_plus_visites' => 'Amosar les visites pa <b>los artículos más visitaos dende l’entamu:</b>',
	'info_comment_lire_tableau' => 'Cómo lleer esti cuadru',
	'info_forum_statistiques' => 'Estadístiques de les visites',
	'info_popularite_2' => 'popularidá del sitiu:',
	'info_popularite_3' => 'popularidá: @popularite@; visites: @visites@',
	'info_popularite_5' => 'popularidá:',
	'info_question_vignettes_referer' => 'Cuando consultes les estadístiques, pues amosar miniatures de los sitios d’orixe de les visites', # MODIF
	'info_question_vignettes_referer_oui' => 'Amosar captures de los sitios d’orixe de les visites',
	'info_visites' => 'visites:',
	'info_visites_plus_populaires' => 'Amosar les visites de <b>los artículos más populares</b> y de <b>los caberos artículos espublizaos:</b>',
	'info_zoom' => 'zoom',
	'item_gerer_statistiques' => 'Xestionar les estadístiques', # MODIF

	// O
	'onglet_origine_visites' => 'Orixe de les visites',
	'onglet_repartition_debut' => 'dende l’entamu',
	'onglet_repartition_lang' => 'Repartío por llingües',

	// R
	'resume' => 'Resume', # MODIF

	// T
	'texte_admin_effacer_stats' => 'Esta orde esborra tolos datos tocantes a les estadístiques de visites al sitiu, incluyendo la popularidá de los artículos.',
	'texte_comment_lire_tableau' => 'El rangu de l’artículu, na clasificación por popularidá, vién indicáu nel marxe; la popularidá de l’artículu (una estimación del númberu de visites diaries que recibirá si el ritmu actual de consultes se mantuviere) y el númberu de visites recibíes dende’l so espublizamientu amuésense na burbuya que apaez al pasar el mur pol títulu.',
	'texte_signification' => 'Les barres escures representen les entráes acumuláes (total de les sub-estayes), les barres clares el númberu de visites pa cada estaya.',
	'titre_evolution_visite' => 'Evolución de les visites',
	'titre_liens_entrants' => 'Enllaces entrantes',
	'titre_page_statistiques' => 'Estadístiques por estayes',
	'titre_page_statistiques_visites' => 'Estadístiques de les visites',
];
